@@ -163,10 +163,10 @@ class BaseWritter(Writer):
             lib_flag = "-l" + str(splits[-1])
             if len(splits) == 2:
                 prefix = splits[0]
-                if prefix == "static":
-                    lib_flag = "-l:" + "lib" + splits[-1] + ".a"
-                elif prefix == "path":
+                if prefix == "path":
                     lib_flag = splits[-1]
+                elif prefix == "file":
+                    lib_flag = "-l:" + splits[-1]
                 else:
                     raise NotImplementedError("unsupported lib prefix. supported: static and path")
             lib_flags.append(lib_flag)
